********************************************************************************
* 1c. Age youngest Child to Biography data 
********************************************************************************
/*In cases of twins and higher orders of multiple births, separate episodes are generated for each child. The enumerator variable child identifies children within 
respondents. a child episode was skipped in the interview if the respondent reported that the child was deceased. */

*generated variables in "children" that is based on spchild
	
*global SUF "14-0-0"										// set release	
	
	use "$orig_5\SC5_spChild_D_${SUF}.dta", clear

	*keep only harmonized spells per child 
	keep if subspell==0

	*nepsmiss _all
 
	fre ts3320m ts3320y
	egen miss = rowmiss(ts3320m ts3320y)
	fre miss

	drop if miss>0 
	drop miss

	*date of interview = Mai Cawi
	gen intdate = ym(2020,5)
	format intdate %tm
	lab var intdate "date of interview"
	tab intdate

// drop children 

	*reduce to children alive 
	fre diedwave
	drop if diedwave==12 
	drop diedwave 
		
	*reduce to children living (partly) in household 
	fre ts3333c							
	drop if ts3333c==3
	
	
// generate: youngest child's age at interview date 

	*create a Stata monthly date (months since 1960m1) of the birth variables
	fre ts3320y ts3320m
	mvdecode ts3320y ts3320m, mv(-98 -97)
	recode ts3320m (21=2) (24=4) (27=7) (30=10) (32=11) (mis=7) if ts3320y!=. 
		
	rename (ts3320y ts3320m) (kbirthyear kbirthmon)
	generate kbirthym =ym(kbirthyear,kbirthmon)
	format kbirthym %tm
	lab var kbirthym "date of birth youngest child"
	fre kbirthym

	*create age variables 
		gen kagem=(intdate-kbirthym) if kbirthym!=. 
		lab var kagem "age youngest child in months"

		gen kageym=(intdate-kbirthym)/12 if kbirthym!=. 
		lab var kageym "age youngest child in years and decimal months"

		gen kagey = round(kageym) 
		lab var kagey "age youngest child in yeare"
		
// Number of kids at certain age in household 

	duplicates report ID_t child 
	
	*age dummies for each child 
	gen kinder_u3_d=1 if kagey<3
	gen kinder_u6_d=1 if kagey<6
	gen kinder_u10_d=1 if kagey<10
	gen kinder_u14_d=1 if kagey<14
		
	*indicator for children of number of children in certain age groups in household (in all rows)
	bys ID_t (child): generate tx20000=_N if kagey!=. 
	bys ID_t kinder_u3_d (child): generate kinder_u3=_N if kagey<3
	bys ID_t kinder_u6_d (child): generate tx20001=_N if kagey<6	
	bys ID_t kinder_u10_d (child): generate kinder_u10=_N if kagey<10
	bys ID_t kinder_u14_d (child): generate tx20002=_N if kagey<14	
	
		
* identify twins and keep only one (NEPS Forum, Ralf Kuenster, https://forum.lifbi.de/t/sc6-kinder-child-id-in-spchild-cohab/3699)
duplicates report ID_t kbirthym child	
duplicates report ID_t kbirthym			

	sort ID_t kbirthym child
	gen twin = 0
	gen doppel = 0
	replace twin = 1 if ID_t == ID_t[_n-1] & kbirthym == kbirthym[_n-1] & wave == wave[_n-1]		
	replace twin = 1 if ID_t == ID_t[_n+1] & kbirthym == kbirthym[_n+1] & wave == wave[_n+1]
	replace doppel = 1 if ID_t == ID_t[_n-1] & kbirthym == kbirthym[_n-1] & wave != wave[_n-1]		
	replace doppel = 1 if ID_t == ID_t[_n+1] & kbirthym == kbirthym[_n+1] & wave != wave[_n+1]

	lab var doppel "child is observed multiple times due to Widerspruch in previous waves but current observation"
	lab var twin "child has a twin"
	tab1 doppel twin

	*keep only one twin 
	bys ID_t kbirthym: gen help=_n
	keep if help==1
	drop help 
	
	tab1 doppel twin
	duplicates report ID_t kbirthym	

//keep only youngest hchild 
	bys ID_t (child kbirthym): gen help=_n
	bys ID_t (child kbirthym): gen help2=_N
	keep if help==help2	
	drop help help2
	
	duplicates report ID_t	
		
	*clear
	keep ID_t kinder_* tx20000 tx20001 tx20002 kagey kageym kagem kbirthym 

*	
save "$temp\Help_SC5_child.dta", replace
*
