********************************************************************************
* Corona-Well-being JFR
* Bächmann / Vicari / Zoch
* created 11.01.2021, last changes: 04.10.
********************************************************************************
est clear
capture log close 
set more off, perm
version 16.1
set scrollbufsize  100000
graph set window fontface "Calibri"

	colorpalette "0 119 170"  "173  0  95" "40  35  94"

	grstyle clear

	grstyle init
	grstyle color background white
	grstyle set color "0  80  114"
	
	
log using "$log\0_JFR_Final_Analyses_${date}.log", replace	

// set output folder
cd "${out}\"


// set missings
misstable summarize sex dsatlife caresing corbetreu_not workmore homeoffice_or income_cov age migration casmin2_d5 kinder_u6 t741001 ost tz_dum_or tz_dum


	egen miss=rowmiss(sex dsatlife caresing corbetreu_not workmore homeoffice income_cov age migration tz_dum casmin2_d5 ost)	
	tab miss scpre,m 


***************************************************
*** Descriptives 
***************************************************
		
	*Mean comparison pre-post corona (weighted -> Text) 
	**
	clonevar graph_satlife = satlife	// before pandemic 
	mean graph_satlife if miss==0  [aweight=w_tC_cal], over(sex)
	est store m1
	drop graph_satlife
	
	clonevar graph_satlife = csatlife	// pandemic 
	mean graph_satlife if miss==0  [aweight=w_tC_cal], over(sex)
	est store m2
	drop graph_satlife	
	
	coefplot (m1, label(pre-corona)) (m2, label(May-June 2020)), ///
				coeflabels(	c.graph_satlife@0.sex=fathers ///
						c.graph_satlife@1.sex=mothers ) levels(90)
		
		
	*Figure 1: Change life-satisfaction  
	**	
		twoway 	(histogram dsatlife if sex, width(1) start(-7) color(grey%30) disc freq xlabel(-7(1)7, grid)) /// 
		         (histogram dsatlife if !sex, width(1) start(-7) color(navy%30) disc freq xlabel(-7(1)7, grid)) if miss==0, xline(0) ///
				 legend(order(1 "Mothers" 2 "Fathers")) xtitle(" " "Change in life satisfaction") ytitle("Number of respondents") 
		
				graph export "Abbildung1_hist_numb.png", replace

		
		twoway 	(histogram dsatlife if sex, width(1) start(-7) color(grey%30) disc   xlabel(-7(1)7, grid)) /// 
		         (histogram dsatlife if !sex, width(1) start(-7) color(navy%30) disc  xlabel(-7(1)7, grid)) if miss==0, xline(0) ///
				 legend(order(1 "Mothers" 2 "Fathers")) xtitle(" " "Change in life satisfaction") 
			   
				graph export "Abbildung1_hist.png", replace
									
	
	*Table 1: 
	**	
	
	des satlife csatlife dsatlife ///
			caresing corbetreu_not age casmin2_d5 t741001 kinder_u6 tz_dum_or tz_dum_m ft_couple ft_couple_m income_cov ost workmore homeoffice income_cov sorgen einsam

	tabstat satlife csatlife dsatlife ///
			caresing corbetreu_not age casmin2_d5 t741001 kinder_u6 tz_dum_or tz_dum_m ft_couple ft_couple_m income_cov ost workmore homeoffice income_cov sorgen einsam ///
			if miss==0 , 	stat(mean sd N) by(sex) format(%9.2f) col(stat) 
		
		ttable2 satlife csatlife dsatlife ///
		caresing corbetreu_not age casmin2_d5 t741001 kinder_u6 tz_dum_or tz_dum_m ft_couple ft_couple_m income_cov ost workmore homeoffice income_cov sorgen einsam if miss==0, by(sex) format(%9.2f)
		
		pwcorr sex caresing corbetreu_not age casmin2_d5 t741001 kinder_u6 tz_dum_or tz_dum_m ft_couple ft_couple_m income_cov ost workmore homeoffice income_cov sorgen einsam if miss==0, sig star(0.05) 

					
	*check with weights
	tabstat satlife csatlife dsatlife ///
			caresing corbetreu_not age casmin2_d5 t741001 kinder_u6 tz_dum_or tz_dum_m ft_couple ft_couple_m income_cov ost workmore homeoffice income_cov sorgen einsam ///
			if miss==0  [aweight=w_tC_cal], stat(mean sd N) by(sex) format(%9.2f) col(stat) 
			

	*Care
	tab caresing if miss==0, m 
	
	tab caresing sex if miss==0 , m row col 
	tab caresing sex if miss==0 [aweight=w_tC_cal], m row col 

	tab corbetreu_not sex if miss==0, m row col	
	tab corbetreu_not sex if miss==0 [aweight=w_tC_cal], m row col
		

	
**************************************************************************************************************************
* OLS - Changes scores models 
**************************************************************************************************************************
	
	// overall model 
	
	global controls c.age t741001 kinder_u6 i.tz_dum i.tz_dum_m  ft_couple ft_couple_m income_cov i.ost  // casmin2_d5 
		
				qui reg dsatlife 		 i.sex if miss==0, vce(robust)
				est store satlife_m1
				
				qui reg dsatlife 		 i.sex $controls if miss==0, vce(robust)
				est store satlife_m2
								
				qui reg dsatlife 		 i.sex $controls i.workmore i.homeoffice if miss==0, vce(robust)
				est store satlife_m3					
				
				qui reg dsatlife		 i.sex $controls i.workmore i.homeoffice i.caresing i.corbetreu_not if miss==0, vce(robust)
				est store satlife_m4
	
				qui reg dsatlife 		 i.sex $controls i.workmore i.homeoffice i.caresing i.corbetreu_not einsam sorgen if miss==0, vce(robust)
				est store satlife_m5		
								
				esttab satlife_m? , star(+ 0.10 * 0.05 ** 0.01 *** 0.001) b(%9.2f) sfmt(%9.2f) se(%9.2f) scalars(N r2_a p)  nobaselevels   ///
				coeflabels (1.sex "Female (ref. male)" 1.caresing  "Primary caregiver (ref. shared care)"  1.corbetreu_not "Emergency care" /// 
				age "age" t741001 "Household size" kinder_u6_d "Child(ren) under 6" 1.ost "East Germany (ref. west)" income_cov "Decreased houshold income"  ///
				1.tz_dum "work: part-time" 1.tz_dum_m "work: ." ft_couple "work partner: full-time" ft_couple_m "work partner: ." ///
				1.workmore "Working more hours" 1.homeoffice "Working remotely" homeoffice_m "remote ." sorgen "Being concerned" einsam "Feeling lonely" )
				
		*check multicolinearity		
		estat vif 					
					
							
	// sample split 

		foreach sex in 0 1 {
				qui reg dsatlife 		  $controls if miss==0 & sex==`sex', vce(robust)
				est store satlife_`sex'_s1

				qui reg dsatlife 		   $controls i.workmore if miss==0 & sex==`sex', vce(robust)
				est store satlife_`sex'_s2			
				
				qui reg dsatlife 		   $controls i.workmore i.homeoffice  if miss==0 & sex==`sex', vce(robust)
				est store satlife_`sex'_s3		
				
				qui reg dsatlife 		   $controls i.workmore i.homeoffice i.caresing i.corbetreu_not if miss==0 & sex==`sex', vce(robust)
				est store satlife_`sex'_s4			
				
				qui reg dsatlife 		   $controls i.workmore i.homeoffice i.caresing  i.corbetreu_not einsam sorgen if miss==0 & sex==`sex', vce(robust)
				est store satlife_`sex'_s5	
				
				*check multicolinearity		
				estat vif 
		}
								
			// Men 
			esttab satlife_0_s? , star(+ 0.10 * 0.05 ** 0.01 *** 0.001) b(%9.2f) sfmt(%9.2f) se(%9.2f) scalars(N r2_a p) nobaselevels ///
							coeflabels (1.sex "Female" 1.caresing  "primary caregiver"  1.corbetreu_not "emergency care" 1.sex#1.caresing "fem#SC" /// 
							age "age" c.age#c.age "age²" kinder_u6_d "children under 6" 1.migration "migration background (ref. none)" 1.ost "East Germany (ref. west)" t741001 "household size" ///
							1.tz_dum "work: part-time" 1.tz_dum_m "work ." 1.familie_sc26 "single parent (ref. not)" grarole "trad roles" 1.ykind "child 14+"  2.ykind "child 0-6" ///
							1.etsysrel "system-relevant" 1.workmore "more h" 1.homeoffice "remote " homeoffice_m "remote ."  )
							
			// Women 			
			esttab satlife_1_s? , star(+ 0.10 * 0.05 ** 0.01 *** 0.001) b(%9.2f) sfmt(%9.2f) se(%9.2f) scalars(N r2_a p) nobaselevels ///
							coeflabels (1.sex "female" 1.caresing  "primary caregiver"  1.corbetreu_not "emergency care" 1.sex#1.caresing "fem#SC" /// 
							age "age" c.age#c.age "age²" kinder_u6_d "children under 6" 1.migration "migration background (ref. none)" 1.ost "East Germany (ref. west)" t741001 "household size" ///
							1.tz_dum "work: part-time" 1.tz_dum_m "work ." 1.familie_sc26 "single parent (ref. not)" grarole "trad roles" 1.ykind "child 14+"  2.ykind "child 0-6" ///
							1.etsysrel "system-relevant" 1.workmore "more h" 1.homeoffice "remote " homeoffice_m "remote ."  )					

		
				
				
				// Output: Table 2			
				esttab satlife_m? satlife_0_s5 satlife_1_s5, star(+ 0.10 * 0.05 ** 0.01 *** 0.001) b(%9.2f) sfmt(%9.2f) se(%9.2f) scalars(N r2_a p)  nobaselevels   ///
				coeflabels (1.sex "Female (ref. male)" 1.caresing  "Primary caregiver (ref. shared care)"  1.corbetreu_not "Emergency care" /// 
				age "age" t741001 "Household size" kinder_u6_d "Child(ren) under 6" 1.ost "East Germany (ref. west)" income_cov "Decreased houshold income"  ///
				1.tz_dum "work: part-time" 1.tz_dum_m "work: ." ft_couple "work partner: full-time" ft_couple_m "work partner: ." ///
				1.workmore "Working more hours" 1.homeoffice "Working remotely" homeoffice_m "remote ." sorgen "Being concerned" einsam "Feeling lonely" )
				
							
							// Output Tables 					
							esttab satlife_m? satlife_0_s5 satlife_1_s5 using "Table.rtf", replace star(+ 0.10 * 0.05 ** 0.01 *** 0.001) b(%9.2f) sfmt(%9.2f) se(%9.2f) scalars(N r2_a p) nobaselevels  ///
							coeflabels (1.sex "Female (ref. male)" 1.caresing  "Primary caregiver (ref. shared care)"  1.corbetreu_not "Emergency care" /// 
							age "age" t741001 "Household size" kinder_u6_d "Child(ren) under 6" 1.ost "East Germany (ref. west)" income_cov "Decreased houshold income"  ///
							1.tz_dum "work: part-time" 1.tz_dum_m "work: ." ft_couple "work partner: full-time" ft_couple_m "work partner: ." ///
							1.workmore "Working more hours" 1.homeoffice "Working remotely" homeoffice_m "remote ." sorgen "Being concerned" einsam "Feeling lonely" )
			
	
							// Output Graphik 
							coefplot 	(satlife_0_s5 , msymbol(Th) mlcolor(navy) mfcolor(navy) ciopts(lcol(navy)) label(Fathers)) ///
										(satlife_1_s5, msymbol(C)  label(Mothers)) , xline(0) levels(90) ///
										coeflabels (1.caresing="Primary caregiver"  1.corbetreu_not="Emergency care" /// 
											age="Age" t741001="Household size" kinder_u6_d="Child(ren) under 6" 1.ost="East Germany" income_cov="Decreased HH-Income" ///
											1.tz_dum="Work: part-time" 1.tz_dum_m="Work: ." ft_couple="Work partner: full-time" ft_couple_m="Work partner: ." ///
											1.workmore="Working more" 1.homeoffice="Working remotely" homeoffice_m="remote ." sorgen="Being concerned" einsam ="Feeling lonely") ///
											saving(coeff, replace) title("Coefficients", size(mlarge)) drop(_cons) xsize(3)	
							
							qui reg dsatlife 		 i.sex $controls i.workmore i.homeoffice i.caresing i.corbetreu_not einsam sorgen if miss==0, vce(robust)
							qui margins i.sex 
							marginsplot,  saving(m8, replace) horizontal xlabel(-1.5(0.5)0.5)level(90) xsize(1)  recast(bar)  plotopts(barw(.8)) ytitle (" ") xtitle(" " "Change in Satisfaction")  ///
							title("Predicted Change in Satisfaction", size(mlarge)) ylabel (0 "Fathers" 1 "Mothers") 
							
							graph combine coeff.gph m8.gph, iscale(0.8)  				
							graph export "Abbildung2_OLS_UVs_samplesplit.png", replace	
		
	
	
							// check gender differences in joint models
							
							global controls_i c.age c.t741001 i.kinder_u6 i.tz_dum i.tz_dum_m  i.ft_couple i.ft_couple_m i.income_cov i.ost 
							
							qui reg dsatlife i.sex##($controls_i) if miss==0 , vce(robust)
							est store satlife_i1

							qui reg dsatlife i.sex##($controls_i i.workmore) if miss==0 , vce(robust)
							est store satlife_i2
							
							qui reg dsatlife i.sex##($controls_i i.workmore i.homeoffice ) if miss==0 , vce(robust)
							est store satlife_i3
							
							qui reg dsatlife i.sex##($controls_i i.workmore i.homeoffice i.caresing i.corbetreu_not ) if miss==0 , vce(robust)
							est store satlife_i4
							
							qui reg dsatlife i.sex##($controls_i i.workmore i.homeoffice i.caresing  i.corbetreu_not c.einsam c.sorgen) if miss==0 , vce(robust)
							est store satlife_i5
							
							esttab satlife_i* , star(+ 0.10 * 0.05 ** 0.01 *** 0.001) b(%9.2f) sfmt(%9.2f) se(%9.2f) scalars(N r2_a p) nobaselevels ///
							coeflabels (1.sex "Female" 1.caresing  "primary caregiver"  1.corbetreu_not "emergency care" 1.sex#1.caresing "fem#SC" /// 
							age "age" c.age#c.age "age²" kinder_u6_d "children under 6" 1.migration "migration background (ref. none)" 1.ost "East Germany (ref. west)" t741001 "household size" ///
							1.tz_dum "work: part-time" 1.tz_dum_m "work ." 1.familie_sc26 "single parent (ref. not)" grarole "trad roles" 1.ykind "child 14+"  2.ykind "child 0-6" ///
							1.etsysrel "system-relevant" 1.workmore "more h" 1.homeoffice "remote " homeoffice_m "remote ."  )
							
								

		// Interactions 
	
		foreach sex in 0 1 {
			foreach var in satlife  {

					*single-care#children u6					
					global controls c.age income_cov i.ost t741001  		
		
						qui reg d`var' 		i.caresing##i.kinder_u6 $controls if miss==0 & sex==`sex', vce(robust)
						est store `var'_`sex'_i1
					

					global controls c.age income_cov i.ost t741001 kinder_u6 

					*single-care#high educ		
					qui reg d`var' 		i.caresing##i.casmin2_d5 $controls if miss==0 & sex==`sex', vce(robust)
					est store `var'_`sex'_i2	
					
					*single-care#TZ before pandemic					
					qui reg d`var' 		i.caresing##i.tz_dum $controls if miss==0 & sex==`sex', vce(robust)
					est store `var'_`sex'_i3

					*single-care#homeoffice				
					qui reg d`var' 		i.caresing##i.homeoffice $controls if miss==0 & sex==`sex', vce(robust)
					est store `var'_`sex'_i4
					
					*single-care#work-more					
					qui reg d`var' 		i.caresing##i.workmore $controls if miss==0 & sex==`sex', vce(robust)
					est store `var'_`sex'_i5
					
					*single-care#income			
					qui reg d`var' 		i.caresing##i.income_cov $controls if miss==0 & sex==`sex', vce(robust)
					est store `var'_`sex'_i6

					}		
			}
		
			coefplot ///
				(satlife_0_i1, msymbol(Th) mlcolor(navy) mfcolor(navy) ciopts(lcol(navy))label(Fathers)) ///
				(satlife_1_i1, msymbol(C)  offset(-0.2)  label(Mothers)), xline(0) xlabel(-2(1)2) levels(90) nolabels ///
				drop(_cons age income_cov 1.ost t741001 kinder_u6_d) saving(a, replace) title(Child under 6) ///
				coeflabels (1.caresing=`""Primary" "caregiver (PC)""' 1.kinder_u6_d=`""Child(ren)" "under 6""' 1.caresing#1.kinder_u6_d=`""PC # Child" "under 6""')
			coefplot ///
				(satlife_0_i2, msymbol(Th) mlcolor(navy) mfcolor(navy) ciopts(lcol(navy)) label(Fathers)) ///
				(satlife_1_i2, msymbol(C)  offset(-0.2)  label(Mothers)), xline(0) xlabel(-2(1)2) levels(90) nolabels ///
				drop(_cons age income_cov 1.ost t741001 kinder_u6_d) saving(b, replace)  title(Tertiary Education) ///
				coeflabels (1.caresing=`""Primary" "caregiver (PC)""' 1.casmin2_d5=`""Tertiary" "education""' 1.caresing#1.casmin2_d5=`""PC # Tertiary" "Education""')
			coefplot ///
				(satlife_0_i3, msymbol(Th) mlcolor(navy) mfcolor(navy) ciopts(lcol(navy)) label(Fathers)) ///
				(satlife_1_i3, msymbol(C)  offset(-0.2)  label(Mothers)), xline(0) xlabel(-2(1)2) levels(90) nolabels ///
				drop(_cons age income_cov 1.ost t741001 kinder_u6_d) saving(c, replace)  title(Part-time work) ///
				coeflabels (1.caresing=`""Primary" "caregiver (PC)""' 1.tz_dum="Part-time" 1.caresing#1.tz_dum=`""PC #" "Part-time""')
			coefplot ///
				(satlife_0_i4, msymbol(Th) mlcolor(navy) mfcolor(navy) ciopts(lcol(navy)) label(Fathers)) ///
				(satlife_1_i4, msymbol(C)  offset(-0.2)  label(Mothers)), xline(0) xlabel(-2(1)2) levels(90) nolabels ///
				drop(_cons age income_cov 1.ost t741001 kinder_u6_d) saving(d, replace)  title(Remote work)  ///
				coeflabels (1.caresing=`""Primary" "caregiver (PC)""' 1.homeoffice=`""Working" "remotely""' 1.caresing#1.homeoffice=`""PC # Working" "Remote""')
			coefplot ///
				(satlife_0_i5, msymbol(Th) mlcolor(navy) mfcolor(navy) ciopts(lcol(navy)) label(Fathers)) ///
				(satlife_1_i5, msymbol(C)  offset(-0.2)  label(Mothers)), xline(0) xlabel(-2(1)2) levels(90) nolabels ///
				drop(_cons age income_cov 1.ost t741001 kinder_u6_d) saving(e, replace)  title(Working more h) 	 ///
				coeflabels (1.caresing=`""Primary" "caregiver (PC)""' 1.workmore=`""Working" "more h""' 1.caresing#1.workmore=`""PC # Working" "more h""')
			coefplot ///
				(satlife_0_i6, msymbol(Th) mlcolor(navy) mfcolor(navy) ciopts(lcol(navy)) label(Fathers)) ///
				(satlife_1_i6, msymbol(C)  offset(-0.2)  label(Mothers)), xline(0) xlabel(-2(1)2) levels(90) nolabels ///
				drop(_cons age income_cov 1.ost t741001 kinder_u6_d) saving(f, replace)  title(Decreased HH-Income) ///
				coeflabels (1.caresing=`""Primary" "caregiver (PC)""' 1.income_cov=`""Decreased" "HH-income""' 1.caresing#1.income_cov=`""PC #" "decr. income""')				
				
			
			gr combine a.gph b.gph c.gph d.gph e.gph f.gph 
			graph export "Abbildung3_OLS_Interactions.png", replace
			
		
		
	
**************************************************************************************************************************
* Robustness Checks 
**************************************************************************************************************************
				
sum satlife if miss==0, de
recode satlife (0/7=1 "low") (8=0 "med") (9/10=2 "high"), gen(satlife_kat_kat)
tab satlife satlife_kat, m
tab satlife sex, col row


				*original
				qui reg dsatlife 		 i.sex i.caresing $controls tz_dum tz_dum_m i.workmore i.homeoffice corbetreu_not sorgen einsam  if miss==0, vce(robust)
				est store satlife_r1	
				
				*with missing category for remote work
				qui reg dsatlife 		 i.sex i.caresing $controls tz_dum tz_dum_m i.workmore i.homeoffice homeoffice_m corbetreu_not sorgen einsam if miss==0, vce(robust)
				est store satlife_r2				
				
				*with lower and upper bound change
				qui reg dsatlife 		 i.sex i.caresing $controls tz_dum tz_dum_m i.workmore i.homeoffice corbetreu_not sorgen einsam i.satlife_kat if miss==0, vce(robust)
				est store satlife_r3				

				*education
				qui reg dsatlife 		 i.sex i.caresing $controls tz_dum tz_dum_m i.workmore i.homeoffice corbetreu_not sorgen einsam i.casmin2_d5 if miss==0, vce(robust)
				est store satlife_r4	
				
				*sub population
				qui reg dsatlife 		 i.sex i.caresing $controls tz_dum tz_dum_m i.workmore i.homeoffice corbetreu_not sorgen einsam i.scpre if miss==0, vce(robust)
				est store satlife_r5				

				
				
				esttab satlife_r? , star(+ 0.10 * 0.05 ** 0.01 *** 0.001) b(%9.2f) sfmt(%9.2f) se(%9.2f) scalars(N r2_a p)  nobaselevels   ///
				coeflabels (1.sex "female" 1.caresing  "c=single"  1.corbetreu_not "c=Not" 1.sex#1.caresing "fem#SC" /// 
				age "age" c.age#c.age "age²" kinder_u6d "children under 6" 1.migration "migration background (ref. none)" 1.ost "East Germany (ref. west)" t741001 "household size" ///
				1.tz_dum "work: part-time" 1.tz_dum_m "work ." 1.familie_sc26 "single parent (ref. not)" grarole "trad roles" 1.ykind "child 14+"  2.ykind "child 0-6" ///
				1.etsysrel "system-relevant" 1.workmore "more h" 1.homeoffice "remote " homeoffice_m "remote ."  )		
				
		
						
log close 	

			